@@ -33,12 +33,15 @@ class parameter(object):
                  parameter_edgesupport=None, parameter_contig_threshold=None,
                  parameter_scaffold_indexer=0, parameter_first_lib=None,
                  parameter_cov_cutoff=None, parameter_tot_assembly_length=None,
-                 parameter_current_NG50=None, parameter_current_LG50=None,
+                 parameter_current_N50=None, parameter_current_L50=None,
                  parameter_hapl_ratio=None, parameter_hapl_threshold=None,
                  parameter_detect_haplotype=None, parameter_detect_duplicate=None,
                  parameter_gff_file=None, parameter_information_file=None,
                  parameter_fosmidpool=None, parameter_extend_paths=None,
-                 parameter_development=None, parameter_plots=None, parameter_path_threshold=None):
+                 parameter_development=None, parameter_plots=None, parameter_path_threshold=None,
+                 path_gaps_estimated =0, parameter_gap_estimations = [],
+                 contamination_mean=None, contamination_stddev = None, contamination_ratio=0,
+                 no_score=None):
 
         # Library information
         # Contig information
@@ -62,8 +65,8 @@ class parameter(object):
         self.first_lib = parameter_first_lib
         self.cov_cutoff = parameter_cov_cutoff
         self.tot_assembly_length = parameter_tot_assembly_length
-        self.current_NG50 = parameter_current_NG50
-        self.current_LG50 = parameter_current_LG50
+        self.current_N50 = parameter_current_N50
+        self.current_L50 = parameter_current_L50
         self.hapl_ratio = parameter_hapl_ratio
         self.hapl_threshold = parameter_hapl_threshold
         self.detect_haplotype = parameter_detect_haplotype
@@ -75,7 +78,16 @@ class parameter(object):
         self.development = parameter_development
         self.plots = parameter_plots
         self.path_threshold = parameter_path_threshold
+        self.no_score = no_score
 
+        # related to gap distances
+        self.path_gaps_estimated = path_gaps_estimated
+        self.gap_estimations = parameter_gap_estimations
+
+        # If MP library (PE contamination)
+        self.contamination_ratio = contamination_ratio
+        self.contamination_mean = contamination_mean
+        self.contamination_stddev = contamination_stddev
 
 class counters(object):
     def __init__(self, param_count=None, param_non_unique=None, param_non_unique_for_scaf=None,
